@@ -1,10 +1,5 @@
-/************************************************************
-
-Copyright (C) 1998, Lucent Technologies
-All rights reserved
-
-************************************************************/
-
+/* RSB #include <u.h>
+#include <libc.h>*/
 #include "map.h"
 
 static double a;
@@ -18,7 +13,7 @@ Xcylequalarea(struct place *place, double *x, double *y)
 }
 
 proj
-cylequalarea(double par)
+cylequalarea(double par, double dummy)
 {
 	struct coord stdp0;
 	if(par > 89.0)
